SystemOrganization addCategory: #ConfigurationOfPillar!

Object subclass: #ConfigurationOfPillar
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfPillar'!

!ConfigurationOfPillar commentStamp: '<historical>' prior: 0!
I describe Pillar's dependencies and versions.!

!ConfigurationOfPillar class methodsFor: 'development support' stamp: 'DamienCassou 10/7/2013 11:10'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfPillar class methodsFor: 'private' stamp: 'DamienCassou 10/7/2013 11:10'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 12/19/2013 13:34'!
catalogChangeLog
	^ 'nothing'! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 12/19/2013 12:12'!
catalogContactInfo
	^ 'The original creator of Pillar (formerly known as ''''the syntax behind the Pier CMS'''') is Lukas Renggli. Nevertheless, *Damien Cassou>damien.cassou@gmail.com* is now the maintainer. The website is at *http://www.smalltalkhub.com/#!!/~Pier/Pillar*.'! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 3/16/2015 19:41'!
catalogDescription
	^ 'Pillar is a wiki-like syntax, its document model, a parser for it, and a set of exporters (e.g., HTML, LaTeX, Markdown...). Pillar is primarily used as the wiki syntax behind the *Pier CMS>http://piercms.com*. Pillar is also being used to write books: e.g., *the Enterprise Pharo book>https://ci.inria.fr/pharo-contribution/job/EnterprisePharoBook/lastSuccessfulBuild/artifact*.'! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 12/19/2013 12:18'!
catalogKeyClassesAndExample
	^ 'The key classes are:

- ==PRDocumentItem== and all its subclasses (e.g., ==PRLink==, ==PRParagraph==, ==PRHeader==, ==PRDocument==). These classes represent the document model.
- ==PRDocumentParser== which takes a pillar-formatted string as input and produces a ==PRDocument== (i.e., the document model) as output. Its main public method is its ==parse:== method on class-side to start the parsing process.
- ==PRVisitor== which provides all the functionality to navigate the document model.
- ==PRDocumentWriter2== is the superclass of all classes supposed to output a pier document model to a text file. Its subclasses include one to output a LaTeX document and one to output an HTML webpage.

From Pharo, you can create an HTML out of a Pillar-formatted string by writing a code similar to:

[[[language=Smalltalk
PRHTMLWriter defaultConfigurations anyOne
    inputString: ''Some text with *a link to Pharo>http://www.pharo.org*.'';
    outputFile: ''myFirstPillarExport.html'' asFileReference;
    export
]]]

Executing this code will result in the creation of a ==myFirstPillarExport.html== file with this content:

[[[language=html
<p>Some text with <a href="http://www.pharo.org">a link to Pharo</a>.</p>
]]]
'! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 12/19/2013 11:41'!
catalogKeywords
	^ #(pier book wiki html latex markdown)! !

!ConfigurationOfPillar class methodsFor: 'private' stamp: 'DamienCassou 10/7/2013 11:10'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfPillar class methodsFor: 'private' stamp: 'DamienCassou 10/7/2013 11:10'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfPillar class methodsFor: 'metacello tool support' stamp: 'DamienCassou 10/7/2013 11:10'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfPillar class methodsFor: 'loading' stamp: 'DamienCassou 10/7/2013 11:10'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfPillar class methodsFor: 'loading' stamp: 'DamienCassou 10/7/2013 11:10'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfPillar class methodsFor: 'loading' stamp: 'DamienCassou 10/7/2013 11:10'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfPillar class methodsFor: 'loading' stamp: 'DamienCassou 4/3/2015 13:46'!
loadStable
	"Load the #stable version defined for this platform.."

	"self loadStable"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfPillar class methodsFor: 'accessing' stamp: 'DamienCassou 10/7/2013 11:10'!
project

	^self new project! !

!ConfigurationOfPillar class methodsFor: 'development support' stamp: 'DamienCassou 10/7/2013 11:10'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'DamienCassou 2/19/2014 11:07'!
baseline010: spec

	<version: '0.10-baseline'>
	spec
		for: #common
		do: [ 
			spec
				blessing: #baseline;
				repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/';
				package: 'Pillar-Model' with: [ spec requires: #('Grease') ];
				package: 'Pillar-ExporterCore' with: [ spec requires: #('Pillar-Model' 'Mustache' 'STON') ];
				package: 'Pillar-Tests-Model' with: [ spec requires: #('Pillar-Model') ];
				package: 'Pillar-Tests-ExporterCore' with: [ spec requires: #('Pillar-Tests-Model' 'Pillar-ExporterCore') ];
				package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-ExporterLaTeX' with: [ spec requires: 'Pillar-ExporterCore' ];
				package: 'Pillar-Tests-ExporterLaTeX'
					with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-ExporterMarkdown' with: [ spec requires: 'Pillar-ExporterCore' ];
				package: 'Pillar-Tests-ExporterMarkdown'
					with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-ExporterCore') ].
			spec
				group: 'html' with: 'Pillar-ExporterHTML';
				group: 'html tests' with: 'Pillar-Tests-ExporterHTML';
				group: 'latex' with: 'Pillar-ExporterLaTeX';
				group: 'latex tests' with: 'Pillar-Tests-ExporterLaTeX';
				group: 'markdown' with: 'Pillar-ExporterMarkdown';
				group: 'markdown tests' with: 'Pillar-Tests-ExporterMarkdown';
				group: 'All exporters' with: #('html' 'latex' 'markdown');
				group: 'All exporter tests' with: #('html tests' 'latex tests' 'markdown tests');
				group: 'All tests' with: #('All exporter tests' 'Pillar-Tests-Model' 'Pillar-Tests-ExporterCore');
				group: 'All but tests' with: #('All exporters');
				group: 'ALL' with: #('All tests' 'All but tests').
			self
				grease: spec;
				mustache: spec;
				ston: spec ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec package: 'Pillar-Cli' with: [ spec requires: 'Pillar-ExporterCore' ].
			spec group: 'All but tests' with: #('Pillar-Cli') ]! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'DamienCassou 3/6/2014 10:37'!
baseline011: spec
	<version: '0.11-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/'.
			self
				grease: spec;
				mustache: spec;
				ston: spec.
			spec
				package: 'Pillar-Model' with: [ spec requires: #('Grease') ];
				package: 'Pillar-Tests-Model'
					with: [ spec requires: #('Pillar-Model' 'Pillar-ExporterPillar' 'Pillar-ExporterText') ];
				package: 'Pillar-ExporterCore' with: [ spec requires: #('Pillar-Model' 'Mustache' 'STON') ];
				package: 'Pillar-ExporterMarkdown' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterLaTeX' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterPillar' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterText' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterCore' with: [ spec requires: #('Pillar-Tests-Model' 'Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterMarkdown'
					with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterLaTeX'
					with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterPillar'
					with: [ spec requires: #('Pillar-ExporterPillar' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterText' with: [ spec requires: #('Pillar-ExporterText' 'Pillar-Tests-ExporterCore') ].
			spec
				group: 'html exporter' with: #('Pillar-ExporterHTML');
				group: 'html exporter tests' with: #('Pillar-Tests-ExporterHTML');
				group: 'latex exporter' with: #('Pillar-ExporterLaTeX');
				group: 'latex exporter tests' with: #('Pillar-Tests-ExporterLaTeX');
				group: 'markdown exporter' with: #('Pillar-ExporterMarkdown');
				group: 'markdown exporter tests' with: #('Pillar-Tests-ExporterMarkdown');
				group: 'pillar exporter' with: #('Pillar-ExporterPillar');
				group: 'pillar exporter tests' with: #('Pillar-Tests-ExporterPillar');
				group: 'text exporter' with: #('Pillar-ExporterText');
				group: 'text exporter tests' with: #('Pillar-Tests-ExporterText');
				group: 'All exporters'
					with: #('html exporter' 'latex exporter' 'markdown exporter' 'pillar exporter' 'text exporter');
				group: 'All exporter tests'
					with:
						#('html exporter tests' 'latex exporter tests' 'markdown exporter tests' 'pillar exporter tests' 'text exporter tests');
				group: 'All tests' with: #('All exporter tests' 'Pillar-Tests-Model' 'Pillar-Tests-ExporterCore');
				group: 'All but tests' with: #('All exporters');
				group: 'ALL' with: #('All tests' 'All but tests') ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec
				package: 'Pillar-PharoInspector' with: [ spec requires: #('Pillar-Model' 'Pillar-ExporterPillar') ];
				package: 'Pillar-Cli' with: [ spec requires: 'Pillar-ExporterCore' ];
				group: 'All but tests' with: #('Pillar-Cli' 'Pillar-PharoInspector') ]! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'DamienCassou 6/6/2014 17:01'!
baseline012: spec
	<version: '0.12-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/'.
			self
				grease: spec;
				mustache: spec;
				ston: spec.
			spec
				package: 'Pillar-Model' with: [ spec requires: #('Grease') ];
				package: 'Pillar-Tests-Model'
					with: [ spec requires: #('Pillar-Model' 'Pillar-ExporterPillar' 'Pillar-ExporterText') ];
				package: 'Pillar-ExporterCore' with: [ spec requires: #('Pillar-Model' 'Mustache' 'STON') ];
				package: 'Pillar-ExporterMarkdown' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterLaTeX' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterPillar' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterText' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterCore' with: [ spec requires: #('Pillar-Tests-Model' 'Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterMarkdown'
					with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterLaTeX'
					with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterPillar'
					with: [ spec requires: #('Pillar-ExporterPillar' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterText' with: [ spec requires: #('Pillar-ExporterText' 'Pillar-Tests-ExporterCore') ].
			spec
				group: 'html exporter' with: #('Pillar-ExporterHTML');
				group: 'html exporter tests' with: #('Pillar-Tests-ExporterHTML');
				group: 'latex exporter' with: #('Pillar-ExporterLaTeX');
				group: 'latex exporter tests' with: #('Pillar-Tests-ExporterLaTeX');
				group: 'markdown exporter' with: #('Pillar-ExporterMarkdown');
				group: 'markdown exporter tests' with: #('Pillar-Tests-ExporterMarkdown');
				group: 'pillar exporter' with: #('Pillar-ExporterPillar');
				group: 'pillar exporter tests' with: #('Pillar-Tests-ExporterPillar');
				group: 'text exporter' with: #('Pillar-ExporterText');
				group: 'text exporter tests' with: #('Pillar-Tests-ExporterText');
				group: 'All exporters'
					with: #('html exporter' 'latex exporter' 'markdown exporter' 'pillar exporter' 'text exporter');
				group: 'All exporter tests'
					with:
						#('html exporter tests' 'latex exporter tests' 'markdown exporter tests' 'pillar exporter tests' 'text exporter tests');
				group: 'All tests' with: #('All exporter tests' 'Pillar-Tests-Model' 'Pillar-Tests-ExporterCore');
				group: 'All but tests' with: #('All exporters');
				group: 'ALL' with: #('All tests' 'All but tests') ].
	spec
		for: #pharo
		do: [ 
			spec
				package: 'Pillar-PharoInspector' with: [ spec requires: #('Pillar-Model' 'Pillar-ExporterPillar') ];
				package: 'Pillar-Cli' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-GitBook' with: [ spec requires: #('Pillar-Cli' 'markdown exporter' 'text exporter') ];
				group: 'All but tests' with: #('Pillar-Cli' 'Pillar-PharoInspector' 'Pillar-GitBook') ]! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'DiegoLont 2/7/2014 10:24'!
"protocol: accessing"
baseline01: spec
	<version: '0.1-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/'.
			spec package: 'Pillar-Model' with: [ spec requires: #('Grease') ].
			spec package: 'Pillar-Tests-Model' with: [ spec requires: #('Pillar-Model') ].
			spec package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-Model') ].
			spec package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-Model') ].
			spec package: 'Pillar-ExporterLaTeX' with: [ spec requires: 'Pillar-Model' ].
			spec package: 'Pillar-Tests-ExporterLaTeX' with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-Model') ].
			spec package: 'Pillar-ExporterMarkdown' with: [ spec requires: 'Pillar-Model' ].
			spec package: 'Pillar-Tests-ExporterMarkdown' with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-Model') ].
			spec group: 'ALL' with: #('Pillar-Tests-ExporterLaTeX' 'Pillar-Tests-ExporterHTML' 'Pillar-Tests-ExporterMarkdown' ).
			self grease: spec ]! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'TorstenBergmann 3/6/2015 02:05'!
baseline020: spec
	<version: '0.20-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/'.
			self
				grease: spec;
				mustache: spec;
				ston: spec.
			spec
				package: 'Pillar-Model' with: [ spec requires: #('Grease') ];
				package: 'Pillar-Tests-Model'
					with: [ spec requires: #('Pillar-Model' 'Pillar-ExporterPillar' 'Pillar-ExporterText') ];
				package: 'Pillar-ExporterCore' with: [ spec requires: #('Pillar-Model' 'Mustache' 'STON') ];
				package: 'Pillar-ExporterMarkdown' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterLaTeX' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterPillar' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterText' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterCore' with: [ spec requires: #('Pillar-Tests-Model' 'Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterMarkdown'
					with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterLaTeX'
					with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterPillar'
					with: [ spec requires: #('Pillar-ExporterPillar' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterText' with: [ spec requires: #('Pillar-ExporterText' 'Pillar-Tests-ExporterCore') ].
			spec
				group: 'html exporter' with: #('Pillar-ExporterHTML');
				group: 'html exporter tests' with: #('Pillar-Tests-ExporterHTML');
				group: 'latex exporter' with: #('Pillar-ExporterLaTeX');
				group: 'latex exporter tests' with: #('Pillar-Tests-ExporterLaTeX');
				group: 'markdown exporter' with: #('Pillar-ExporterMarkdown');
				group: 'markdown exporter tests' with: #('Pillar-Tests-ExporterMarkdown');
				group: 'pillar exporter' with: #('Pillar-ExporterPillar');
				group: 'pillar exporter tests' with: #('Pillar-Tests-ExporterPillar');
				group: 'text exporter' with: #('Pillar-ExporterText');
				group: 'text exporter tests' with: #('Pillar-Tests-ExporterText');
				group: 'All exporters'
					with: #('html exporter' 'latex exporter' 'markdown exporter' 'pillar exporter' 'text exporter');
				group: 'All exporter tests'
					with:
						#('html exporter tests' 'latex exporter tests' 'markdown exporter tests' 'pillar exporter tests' 'text exporter tests');
				group: 'All tests' with: #('All exporter tests' 'Pillar-Tests-Model' 'Pillar-Tests-ExporterCore');
				group: 'All but tests' with: #('All exporters');
				group: 'ALL' with: #('All tests' 'All but tests') ].
	spec
		for: #pharo
		do: [ 
			spec
				package: 'Pillar-Pharo-Tools' with: [ spec requires: #('Pillar-Model' 'Pillar-ExporterPillar') ];
				package: 'Pillar-Cli' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-GitBook' with: [ spec requires: #('Pillar-Cli' 'markdown exporter' 'text exporter') ];
				group: 'All but tests' with: #('Pillar-Cli' 'Pillar-Pharo-Tools' 'Pillar-GitBook') ]! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'CyrilFerlicot 4/1/2015 18:08'!
baseline021: spec
	<version: '0.21-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/'.
			self
				grease: spec;
				mustache: spec;
				cocoon: spec.
			spec
				package: 'Pillar-Model' with: [ spec requires: #('Grease') ];
				package: 'Pillar-Tests-Model'
					with: [ spec requires: #('Pillar-Model' 'Pillar-ExporterPillar' 'Pillar-ExporterText') ];
				package: 'Pillar-ExporterCore' with: [ spec requires: #('Pillar-Model' 'Mustache' 'Cocoon') ];
				package: 'Pillar-ExporterMarkdown' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterLaTeX' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterPillar' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterText' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterCore' with: [ spec requires: #('Pillar-Tests-Model' 'Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterMarkdown'
					with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterLaTeX'
					with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterPillar'
					with: [ spec requires: #('Pillar-ExporterPillar' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterText' with: [ spec requires: #('Pillar-ExporterText' 'Pillar-Tests-ExporterCore') ].
			spec
				group: 'html exporter' with: #('Pillar-ExporterHTML');
				group: 'html exporter tests' with: #('Pillar-Tests-ExporterHTML');
				group: 'latex exporter' with: #('Pillar-ExporterLaTeX');
				group: 'latex exporter tests' with: #('Pillar-Tests-ExporterLaTeX');
				group: 'markdown exporter' with: #('Pillar-ExporterMarkdown');
				group: 'markdown exporter tests' with: #('Pillar-Tests-ExporterMarkdown');
				group: 'pillar exporter' with: #('Pillar-ExporterPillar');
				group: 'pillar exporter tests' with: #('Pillar-Tests-ExporterPillar');
				group: 'text exporter' with: #('Pillar-ExporterText');
				group: 'text exporter tests' with: #('Pillar-Tests-ExporterText');
				group: 'All exporters'
					with: #('html exporter' 'latex exporter' 'markdown exporter' 'pillar exporter' 'text exporter');
				group: 'All exporter tests'
					with:
						#('html exporter tests' 'latex exporter tests' 'markdown exporter tests' 'pillar exporter tests' 'text exporter tests');
				group: 'All tests' with: #('All exporter tests' 'Pillar-Tests-Model' 'Pillar-Tests-ExporterCore');
				group: 'All but tests' with: #('All exporters');
				group: 'ALL' with: #('All tests' 'All but tests') ].
	spec
		for: #pharo
		do: [ 
			spec
				package: 'Pillar-Pharo-Tools' with: [ spec requires: #('Pillar-Model' 'Pillar-ExporterPillar') ];
				package: 'Pillar-Cli' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-GitBook' with: [ spec requires: #('Pillar-Cli' 'markdown exporter' 'text exporter') ];
				group: 'All but tests' with: #('Pillar-Cli' 'Pillar-Pharo-Tools' 'Pillar-GitBook') ]! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'DamienCassou 4/3/2015 13:26'!
baseline022: spec
	<version: '0.22-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/'.
			self
				grease: spec;
				mustache: spec;
				cocoon: spec.
			spec
				package: 'Pillar-Model' with: [ spec requires: #('Grease') ];
				package: 'Pillar-Tests-Model'
					with: [ spec requires: #('Pillar-Model' 'Pillar-ExporterPillar' 'Pillar-ExporterText') ];
				package: 'Pillar-ExporterCore' with: [ spec requires: #('Pillar-Model' 'Mustache' 'Cocoon') ];
				package: 'Pillar-ExporterMarkdown' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterLaTeX' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterBeamer' with: [ spec requires: #('Pillar-ExporterLaTeX') ];
				package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterPillar' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-ExporterText' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterCore' with: [ spec requires: #('Pillar-Tests-Model' 'Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterMarkdown'
					with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterLaTeX'
					with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterBeamer'
					with: [ spec requires: #('Pillar-ExporterBeamer' 'Pillar-Tests-ExporterLaTeX') ];
				package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterPillar'
					with: [ spec requires: #('Pillar-ExporterPillar' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-Tests-ExporterText' with: [ spec requires: #('Pillar-ExporterText' 'Pillar-Tests-ExporterCore') ].
			spec
				group: 'html exporter' with: #('Pillar-ExporterHTML');
				group: 'html exporter tests' with: #('Pillar-Tests-ExporterHTML');
				group: 'latex exporter' with: #('Pillar-ExporterLaTeX');
				group: 'latex exporter tests' with: #('Pillar-Tests-ExporterLaTeX');
				group: 'beamer exporter' with: #('Pillar-ExporterBeamer');
				group: 'beamer exporter tests' with: #('Pillar-Tests-ExporterBeamer');
				group: 'markdown exporter' with: #('Pillar-ExporterMarkdown');
				group: 'markdown exporter tests' with: #('Pillar-Tests-ExporterMarkdown');
				group: 'pillar exporter' with: #('Pillar-ExporterPillar');
				group: 'pillar exporter tests' with: #('Pillar-Tests-ExporterPillar');
				group: 'text exporter' with: #('Pillar-ExporterText');
				group: 'text exporter tests' with: #('Pillar-Tests-ExporterText');
				group: 'All exporters'
					with: #('html exporter' 'latex exporter' 'beamer exporter' 'markdown exporter' 'pillar exporter' 'text exporter');
				group: 'All exporter tests'
					with:
						#('html exporter tests' 'latex exporter tests' 'beamer exporter tests' 'markdown exporter tests' 'pillar exporter tests' 'text exporter tests');
				group: 'All tests' with: #('All exporter tests' 'Pillar-Tests-Model' 'Pillar-Tests-ExporterCore');
				group: 'All but tests' with: #('All exporters');
				group: 'ALL' with: #('All tests' 'All but tests') ].
	spec
		for: #pharo
		do: [ 
			spec
				package: 'Pillar-Pharo-Tools' with: [ spec requires: #('Pillar-Model' 'All exporters') ];
				package: 'Pillar-Cli' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-GitBook' with: [ spec requires: #('Pillar-Cli' 'markdown exporter' 'text exporter') ];
				group: 'All but tests' with: #('Pillar-Cli' 'Pillar-Pharo-Tools' 'Pillar-GitBook') ]! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'DiegoLont 2/7/2014 10:24'!
baseline02: spec
	"protocol: accessing"

	<version: '0.2-baseline'>
	spec
		for: #common
		do: [ 
			spec
				blessing: #baseline;
				repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/';
				package: 'Pillar-Model' with: [ spec requires: #('Grease') ];
				package: 'Pillar-ExporterCore' with: [ spec requires: #('Pillar-Model' 'Mustache' 'STON') ];
				package: 'Pillar-Tests-Model' with: [ spec requires: #('Pillar-Model') ];
				package: 'Pillar-Tests-ExporterCore' with: [ spec requires: #('Pillar-Tests-Model' 'Pillar-ExporterCore') ];
				package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-ExporterLaTeX' with: [ spec requires: 'Pillar-ExporterCore' ];
				package: 'Pillar-Tests-ExporterLaTeX'
					with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-ExporterMarkdown' with: [ spec requires: 'Pillar-ExporterCore' ];
				package: 'Pillar-Tests-ExporterMarkdown'
					with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-ExporterCore') ].
			spec group: 'ALL' with: #('Pillar-Tests-ExporterLaTeX' 'Pillar-Tests-ExporterHTML' 'Pillar-Tests-ExporterMarkdown').
			self
				grease: spec;
				mustache: spec;
				ston: spec ].! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'DiegoLont 2/7/2014 10:24'!
baseline03: spec
	"protocol: accessing"

	<version: '0.3-baseline'>
	spec
		for: #common
		do: [ 
			spec
				blessing: #baseline;
				repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/';
				package: 'Pillar-Model' with: [ spec requires: #('Grease') ];
				package: 'Pillar-ExporterCore' with: [ spec requires: #('Pillar-Model' 'Mustache' 'STON') ];
				package: 'Pillar-Tests-Model' with: [ spec requires: #('Pillar-Model') ];
				package: 'Pillar-Tests-ExporterCore' with: [ spec requires: #('Pillar-Tests-Model' 'Pillar-ExporterCore') ];
				package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-ExporterLaTeX' with: [ spec requires: 'Pillar-ExporterCore' ];
				package: 'Pillar-Tests-ExporterLaTeX'
					with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-ExporterMarkdown' with: [ spec requires: 'Pillar-ExporterCore' ];
				package: 'Pillar-Tests-ExporterMarkdown'
					with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-ExporterCore') ].
			spec
				group: 'html' with: 'Pillar-ExporterHTML';
				group: 'html tests' with: 'Pillar-Tests-ExporterHTML';
				group: 'latex' with: 'Pillar-ExporterLaTeX';
				group: 'latex tests' with: 'Pillar-Tests-ExporterLaTeX';
				group: 'markdown' with: 'Pillar-ExporterMarkdown';
				group: 'markdown tests' with: 'Pillar-Tests-ExporterMarkdown';
				group: 'All exporters' with: #('html' 'latex' 'markdown');
				group: 'All exporter tests' with: #('html tests' 'latex tests' 'markdown tests');
				group: 'All tests' with: #('All exporter tests' 'Pillar-Tests-Model' 'Pillar-Tests-ExporterCore');
				group: 'All but tests' with: #('All exporters');
				group: 'ALL' with: #('All tests' 'All but tests').
			self
				grease: spec;
				mustache: spec;
				ston: spec ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec package: 'Pillar-Cli' with: [ spec requires: 'Pillar-ExporterCore' ].
			spec group: 'All but tests' with: #('Pillar-Cli') ]! !

!ConfigurationOfPillar methodsFor: 'dependencies' stamp: 'CyrilFerlicot 4/1/2015 18:10'!
cocoon: spec
	spec
		project: 'Cocoon'
		with: [ 
			spec
				className: 'ConfigurationOfCocoon';
				versionString: #stable;
				repository: 'http://smalltalkhub.com/mc/PharoExtras/Cocoon/main' ]! !

!ConfigurationOfPillar methodsFor: 'accessing' stamp: 'DamienCassou 10/7/2013 11:10'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfPillar methodsFor: 'symbolic versions' stamp: 'DamienCassou 4/3/2015 13:22'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.22-baseline'.

	spec for: #'pharo4.x' version: '0.22-baseline'.
! !

!ConfigurationOfPillar methodsFor: 'dependencies' stamp: 'DiegoLont 2/7/2014 10:24'!
grease: spec
	spec
		project: 'Grease'
		with: [ 
			spec
				className: 'ConfigurationOfGrease';
				versionString: #stable;
				loads: #('Core');
				repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main' ]! !

!ConfigurationOfPillar methodsFor: 'dependencies' stamp: 'DiegoLont 2/7/2014 10:24'!
mustache: spec
	spec
		project: 'Mustache'
		with: [ 
			spec
				className: 'ConfigurationOfMustache';
				versionString: #stable;
				loads: #('Core');
				repository: 'http://www.smalltalkhub.com/mc/NorbertHartl/Mustache/main' ]! !

!ConfigurationOfPillar methodsFor: 'accessing' stamp: 'DamienCassou 10/7/2013 11:10'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfPillar methodsFor: 'symbolic versions' stamp: 'DamienCassou 4/6/2015 22:18'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.26'.
	
	spec for: #'pharo4.x' version: '0.26'.
! !

!ConfigurationOfPillar methodsFor: 'dependencies' stamp: 'DiegoLont 2/7/2014 10:24'!
ston: spec
	spec
		project: 'STON'
		with: [ 
			spec
				className: 'ConfigurationOfSton';
				versionString: #stable;
				loads: #('Core');
				repository: 'http://smalltalkhub.com/mc/SvenVanCaekenberghe/STON/main' ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 2/19/2014 11:14'!
version010: spec
	<version: '0.10' imports: #('0.10-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.10'.
		spec author: 'DamienCassou'.
		spec timestamp: '2/19/2014 11:08'.
		spec 
			project: 'Grease' with: '1.1.5';
			project: 'Mustache' with: '0.48';
			project: 'STON' with: '0.7'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.63';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.71';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.39';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.42';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.37';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.27';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienPollet.46';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.30';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.54';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.13'. ].

	spec for: #'pharo3.x' do: [
		spec package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 3/24/2014 16:33'!
version011: spec
	<version: '0.11' imports: #('0.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.11'.
		spec author: 'DamienCassou'.
		spec timestamp: '3/24/2014 16:25'.
		spec 
			project: 'Grease' with: '1.1.6';
			project: 'Mustache' with: '0.50';
			project: 'STON' with: '0.7'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.75';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.51';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.79';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.57';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.50';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.38';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-DamienCassou.9';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-DamienCassou.4';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.51';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.15';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.36';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.30';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-DamienCassou.4';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.4'. ].

	spec for: #'pharo3.x' do: [
		spec 
			package: 'Pillar-PharoInspector' with: 'Pillar-PharoInspector-DamienCassou.1';
			package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 4/15/2014 11:33'!
version012: spec
	<version: '0.12' imports: #('0.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.12'.
		spec author: 'DamienCassou'.
		spec timestamp: '4/15/2014 11:29'.
		spec 
			project: 'Grease' with: '1.1.6';
			project: 'Mustache' with: '0.50';
			project: 'STON' with: '0.7'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.75';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.51';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.80';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.57';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.50';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.39';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-DamienCassou.9';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-DamienCassou.4';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.51';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.15';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.36';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.30';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-DamienCassou.4';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.4'. ].

	spec for: #'pharo3.x' do: [
		spec 
			package: 'Pillar-PharoInspector' with: 'Pillar-PharoInspector-DamienCassou.1';
			package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DiegoLont 5/13/2014 10:54'!
version013: spec
	<version: '0.13' imports: #('0.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.13'.
		spec author: 'DamienCassou'.
		spec timestamp: '4/18/2014 17:44'.
		spec 
			project: 'Grease' with: #'release1.1';
			project: 'Mustache' with: '0.50';
			project: 'STON' with: '0.8'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.75';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.51';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.80';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.57';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.50';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.40';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-DamienCassou.9';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-DamienCassou.4';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.51';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.15';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.36';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.31';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-DamienCassou.4';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.4'. ].

	spec for: #'pharo3.x' do: [
		spec 
			package: 'Pillar-PharoInspector' with: 'Pillar-PharoInspector-DamienCassou.1';
			package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'. ].

! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 6/3/2014 18:03'!
version014: spec
	<version: '0.14' imports: #('0.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.14'.
		spec author: 'DamienCassou'.
		spec timestamp: '6/3/2014 17:49'.
		spec 
			project: 'Grease' with: #'release1.1';
			project: 'Mustache' with: '0.60';
			project: 'STON' with: '0.9'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.81';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.97';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.82';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.58';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.53';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.44';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-DamienCassou.9';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-DamienCassou.4';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.52';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.16';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.82';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.32';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-DamienCassou.5';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.6'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-PharoInspector' with: 'Pillar-PharoInspector-DamienCassou.1';
			package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 6/5/2014 14:38'!
version015: spec
	<version: '0.15' imports: #('0.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.15'.
		spec author: 'DamienCassou'.
		spec timestamp: '6/5/2014 14:36'.
		spec 
			project: 'Grease' with: #'release1.1';
			project: 'Mustache' with: '0.60';
			project: 'STON' with: '0.9'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.82';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.97';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.84';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-BenComan.54';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-BenComan.45';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-DamienCassou.9';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-DamienCassou.4';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.56';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-BenComan.83';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-BenComan.7'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-PharoInspector' with: 'Pillar-PharoInspector-DamienCassou.1';
			package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 6/6/2014 17:38'!
version016: spec
	<version: '0.16' imports: #('0.12-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.16'.
		spec author: 'DamienCassou'.
		spec timestamp: '6/6/2014 17:38'.
		spec 
			project: 'Grease' with: #'release1.1';
			project: 'Mustache' with: '0.60';
			project: 'STON' with: '0.9'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.83';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.97';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.84';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-BenComan.54';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.46';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-DamienCassou.9';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-DamienCassou.5';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.56';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-BenComan.83';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-PharoInspector' with: 'Pillar-PharoInspector-DamienCassou.1';
			package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 12/9/2014 15:17'!
version017: spec
	<version: '0.17' imports: #('0.12-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.17'.
		spec author: 'DamienCassou'.
		spec timestamp: '12/9/2014 15:17'.
		spec 
			project: 'Grease' with: '1.1.11';
			project: 'Mustache' with: '0.60';
			project: 'STON' with: '0.9'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.86';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-JohnCBorden.100';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.84';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.57';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.48';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-DamienCassou.9';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-DamienCassou.5';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.56';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-BenComan.83';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-PharoInspector' with: 'Pillar-PharoInspector-DamienCassou.1';
			package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 1/30/2015 10:10'!
version018: spec
	<version: '0.18' imports: #('0.12-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.18'.
		spec author: 'DamienCassou'.
		spec timestamp: '1/30/2015 10:10'.
		spec 
			project: 'Grease' with: '1.1.13';
			project: 'Mustache' with: '0.71';
			project: 'STON' with: '0.9'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.86';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-JohnCBorden.100';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.84';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.58';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.48';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-DamienCassou.9';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-DamienCassou.5';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.56';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.84';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-PharoInspector' with: 'Pillar-PharoInspector-DamienCassou.1';
			package: 'Pillar-Cli' with: 'Pillar-Cli-TorstenBergmann.8';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 11/28/2013 13:58'!
version01: spec
	"protocol: accessing"

	<version: '0.1' imports: #('0.1-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.34';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.18';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.23';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.27';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.24';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.13';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.15';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.3' ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'TorstenBergmann 3/6/2015 12:57'!
version020: spec
	<version: '0.20' imports: #('0.20-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.20 for Pharo 4'.
		spec author: 'TorstenBergmann'.
		spec timestamp: '3/5/2015 10:10'.
		spec 
			project: 'Grease' with: '1.1.13';
			project: 'Mustache' with: '0.71';
			project: 'STON' with: '0.10'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-TorstenBergmann.87';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-JohnCBorden.100';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-TorstenBergmann.85';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-TorstenBergmann.59';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.48';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-TorstenBergmann.10';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-TorstenBergmann.6';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.56';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.84';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-Pharo-Tools' with: 'Pillar-Pharo-Tools-TorstenBergmann.6';
			package: 'Pillar-Cli' with: 'Pillar-Cli-TorstenBergmann.8';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'CyrilFerlicot 3/31/2015 18:27'!
version021: spec
	<version: '0.21' imports: #('0.20-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.21'.
		spec author: 'CyrilFerlicot'.
		spec timestamp: '3/31/2015 18:27'.
		spec 
			project: 'Grease' with: '1.1.13';
			project: 'Mustache' with: '0.71';
			project: 'STON' with: '0.10'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-TorstenBergmann.87';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-JohnCBorden.100';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-CyrilFerlicot.86';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-TorstenBergmann.59';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.48';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-TorstenBergmann.10';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-TorstenBergmann.6';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-CyrilFerlicot.57';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.84';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-Pharo-Tools' with: 'Pillar-Pharo-Tools-TorstenBergmann.6';
			package: 'Pillar-Cli' with: 'Pillar-Cli-CyrilFerlicot.9';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'CyrilFerlicot 4/1/2015 18:12'!
version022: spec
	<version: '0.22' imports: #('0.21-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.22'.
		spec author: 'CyrilFerlicot'.
		spec timestamp: '4/1/2015 11:24'.
		spec 
			project: 'Grease' with: '1.1.13';
			project: 'Mustache' with: '0.71';
			project: 'Cocoon' with: '1.7'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-TorstenBergmann.87';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-JohnCBorden.100';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-CyrilFerlicot.86';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-TorstenBergmann.59';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.48';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-TorstenBergmann.10';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-TorstenBergmann.6';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-CyrilFerlicot.57';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.84';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-Pharo-Tools' with: 'Pillar-Pharo-Tools-TorstenBergmann.6';
			package: 'Pillar-Cli' with: 'Pillar-Cli-CyrilFerlicot.9';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'CyrilFerlicot 4/2/2015 09:51'!
version023: spec
	<version: '0.23' imports: #('0.21-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.23'.
		spec author: 'CyrilFerlicot'.
		spec timestamp: '4/1/2015 18:21'.
		spec 
			project: 'Grease' with: '1.1.13';
			project: 'Mustache' with: '0.71';
			project: 'Cocoon' with: '1.7'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-TorstenBergmann.87';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-JohnCBorden.100';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-CyrilFerlicot.90';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-TorstenBergmann.59';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.48';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-TorstenBergmann.10';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-TorstenBergmann.6';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-CyrilFerlicot.59';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.84';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-Pharo-Tools' with: 'Pillar-Pharo-Tools-TorstenBergmann.6';
			package: 'Pillar-Cli' with: 'Pillar-Cli-CyrilFerlicot.10';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'CyrilFerlicot 4/2/2015 09:51'!
version024: spec
	<version: '0.24' imports: #('0.21-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.24 - Adaptation of the tests to the new configuration system.'.
		spec author: 'CyrilFerlicot'.
		spec timestamp: '4/2/2015 09:49'.
		spec 
			project: 'Grease' with: '1.1.13';
			project: 'Mustache' with: '0.71';
			project: 'Cocoon' with: '1.7'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-TorstenBergmann.87';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-JohnCBorden.100';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-CyrilFerlicot.90';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-TorstenBergmann.59';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.48';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-TorstenBergmann.10';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-TorstenBergmann.6';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-CyrilFerlicot.60';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.84';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-Pharo-Tools' with: 'Pillar-Pharo-Tools-TorstenBergmann.6';
			package: 'Pillar-Cli' with: 'Pillar-Cli-CyrilFerlicot.10';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 4/3/2015 13:45'!
version025: spec
	<version: '0.25' imports: #('0.22-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.25 - Add Beamer (experimental export).'.
		spec author: 'DamienCassou'.
		spec timestamp: '2015/04/03 13:39'.
		spec 
			project: 'Grease' with: '1.1.13';
			project: 'Mustache' with: '0.71';
			project: 'Cocoon' with: '1.7'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-TorstenBergmann.87';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-JohnCBorden.100';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.93';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-BenComan.59';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.61';
			package: 'Pillar-ExporterBeamer' with: 'Pillar-ExporterBeamer-DamienCassou.4';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.48';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-TorstenBergmann.10';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-TorstenBergmann.6';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-CyrilFerlicot.60';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.84';
			package: 'Pillar-Tests-ExporterBeamer' with: 'Pillar-Tests-ExporterBeamer-DamienCassou.1';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-Pharo-Tools' with: 'Pillar-Pharo-Tools-DamienCassou.7';
			package: 'Pillar-Cli' with: 'Pillar-Cli-CyrilFerlicot.10';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 4/6/2015 22:17'!
version026: spec
	<version: '0.26' imports: #('0.22-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'version 0.26 - Add transformers.'.
		spec author: 'DamienCassou'.
		spec timestamp: '2015/04/06 22:12'.
		spec 
			project: 'Grease' with: '1.1.13';
			project: 'Mustache' with: '0.71';
			project: 'Cocoon' with: '1.7'.
		spec 
			package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.96';
			package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.106';
			package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.95';
			package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.60';
			package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.62';
			package: 'Pillar-ExporterBeamer' with: 'Pillar-ExporterBeamer-DamienCassou.4';
			package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.49';
			package: 'Pillar-ExporterPillar' with: 'Pillar-ExporterPillar-DamienCassou.15';
			package: 'Pillar-ExporterText' with: 'Pillar-ExporterText-DamienCassou.7';
			package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.62';
			package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-BenComan.18';
			package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.84';
			package: 'Pillar-Tests-ExporterBeamer' with: 'Pillar-Tests-ExporterBeamer-DamienCassou.1';
			package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-BenComan.33';
			package: 'Pillar-Tests-ExporterPillar' with: 'Pillar-Tests-ExporterPillar-BenComan.6';
			package: 'Pillar-Tests-ExporterText' with: 'Pillar-Tests-ExporterText-DamienCassou.8'. ].

	spec for: #'pharo' do: [
		spec 
			package: 'Pillar-Pharo-Tools' with: 'Pillar-Pharo-Tools-DamienCassou.8';
			package: 'Pillar-Cli' with: 'Pillar-Cli-CyrilFerlicot.10';
			package: 'Pillar-GitBook' with: 'Pillar-GitBook-DamienCassou.1'. ].
! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'BenjaminVanRyseghem 1/9/2014 22:48'!
version02: spec
	<version: '0.2' imports: #('0.2-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.37';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.19';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.20';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.29';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.30';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.27';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-BenjaminVanRyseghem.31';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.13';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.16';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.3' ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 1/8/2014 15:30'!
version03: spec
	<version: '0.3' imports: #('0.3-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.39';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.44';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.25';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.30';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.34';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.27';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.27';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.19';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.17';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.4' ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec package: 'Pillar-Cli' with: 'Pillar-Cli-DamienCassou.5'.
			 ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 1/13/2014 11:25'!
version04: spec
	<version: '0.4' imports: #('0.3-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.47';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.57';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.30';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.33';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.47';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.31';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.34';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.24';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.20';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.9' ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'.
			 ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DiegoLont 2/7/2014 10:26'!
version05: spec
	<version: '0.5' imports: #('0.3-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.47';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.58';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.30';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.34';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.47';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.31';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.34';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.24';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.21';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.9' ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'.
			 ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DiegoLont 2/7/2014 10:26'!
version06: spec
	<version: '0.6' imports: #('0.3-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.50';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.68';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.34';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.35';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.48';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.31';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.37';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.24';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.21';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.9' ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'.
			 ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DiegoLont 2/7/2014 10:26'!
version07: spec
	<version: '0.7' imports: #('0.3-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				package: 'Pillar-Model' with: 'Pillar-Model-BenjaminVanRyseghem.51';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-BenjaminVanRyseghem.70';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.36';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.42';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.54';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.33';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.41';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.27';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.27';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.13' ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'.
			 ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DiegoLont 2/7/2014 10:29'!
version08: spec
	<version: '0.8' imports: #('0.3-baseline')>
	spec
		for: #common
		do: [ 
			spec
				description: 'To be filled out.'; 
				blessing: #release.
				
			spec
				project: 'Grease' with: '1.1.5';
				project: 'Mustache' with: '0.48';
				project: 'STON' with: '0.7'.
				
			spec
				package: 'Pillar-Model' with: 'Pillar-Model-BenjaminVanRyseghem.51';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-BenjaminVanRyseghem.70';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.36';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.43';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.54';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.33';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.41';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.27';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.28';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.13' ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'.
			 ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 2/18/2014 18:17'!
version09: spec
	<version: '0.9' imports: #('0.3-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release.
				
			spec
				project: 'Grease' with: '1.1.5';
				project: 'Mustache' with: '0.48';
				project: 'STON' with: '0.7'.
				
			spec
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.62';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.71';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.37';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienPollet.46';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.54';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.39';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.42';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.27';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.30';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.13' ].
	spec
		for: #'pharo3.x'
		do: [ 
			spec package: 'Pillar-Cli' with: 'Pillar-Cli-BenjaminVanRyseghem.7'.
			 ]! !
